{% load cms_tags menu_tags sekizai_tags %}

<!DOCTYPE html>
<html>
    <head>
        <title>{% page_attribute "page_title" %}</title>
        <meta name="robots" content="noindex, nofollow">
        {% render_block "css" %}
    </head>
    <body>
        {% cms_toolbar %}
        <h1>Django-for-runners Test Project</h1>
        <ul class="nav">
            {% show_menu 0 100 100 100 %}
        </ul>
        {% block content %}
            {% placeholder "content" %}
        {% endblock content %}
        {% render_block "js" %}
    </body>
</html>
