# Generated by Django 2.1.8 on 2019-04-02 16:39

from django.db import migrations

# https://github.com/jedie/django-for-runners
from for_runners_project.cli import call_manage_command


def forwards(apps, schema_editor):
    from for_runners.management.commands import recreate_files

    call_manage_command(cmd_class=recreate_files)


class Migration(migrations.Migration):

    dependencies = [("for_runners", "0008_auto_20190402_1731")]

    operations = [migrations.RunPython(forwards, migrations.RunPython.noop)]
