# Generated by Django 2.1.8 on 2019-04-02 16:28

from django.db import migrations, models
import django_tools.file_storage.file_system_storage
import for_runners.models.gpx


class Migration(migrations.Migration):

    dependencies = [
        ('for_runners', '0006_auto_20180902_1958'),
    ]

    operations = [
        migrations.AddField(
            model_name='gpxmodel',
            name='gpx_file',
            field=models.FileField(blank=True, max_length=511, null=True, storage=django_tools.file_storage.file_system_storage.OverwriteFileSystemStorage(create_backups=True), upload_to=for_runners.models.gpx.gpx_upload_path, verbose_name='GPX Track'),
        ),
        migrations.AlterField(
            model_name='gpxmodel',
            name='track_svg',
            field=models.FileField(blank=True, null=True, storage=django_tools.file_storage.file_system_storage.OverwriteFileSystemStorage(create_backups=False), upload_to=for_runners.models.gpx.svg_upload_path, verbose_name='Track SVG'),
        ),
    ]
